@@ -33,10 +33,6 @@ import (
 	"pkg.deepin.com/linglong/pica/tools/log"
 )
 
-var (
-	delMap = make(map[string]bool) // 用来记录跳过的包的映射
-)
-
 type Deb struct {
 	Name         string
 	Id           string
@@ -56,6 +52,7 @@ type Deb struct {
 	Command      []string
 	Sources      []comm.Source
 	Build        []string
+	DelMap       map[string]bool // 用来记录跳过的包的映射，每个Deb实例独立
 }
 
 func (d *Deb) GetPackageUrl(source, distro, arch string) string {
@@ -106,11 +103,7 @@ func (d *Deb) CheckDebHash() bool {
 		d.Hash = hash
 		return false
 	}
-	if hash == d.Hash {
-		return true
-	}
-
-	return true
+	return hash == d.Hash
 }
 
 // FetchDebFile
@@ -242,12 +235,13 @@ func (d *Deb) ResolveDepends(source, distro string, withDep bool) {
 	// 过滤掉 runtime 中安装过的包
 	skipPackage = append(skipPackage, cli.GetRuntimeInsPack()...)
 	filterSlice := strings.Split(filter, ",")
+	d.DelMap = make(map[string]bool) // 初始化为每个Deb独立的map
 	for _, item := range skipPackage {
-		delMap[item] = true
+		d.DelMap[item] = true
 	}
 	var result []string
 	for _, item := range filterSlice {
-		if !delMap[item] {
+		if !d.DelMap[item] {
 			result = append(result, item)
 		}
 	}
@@ -299,13 +293,17 @@ func (d *Deb) ResolveDepends(source, distro string, withDep bool) {
 }
 
 func (d *Deb) GenerateBuildScript() {
-	d.Build = append(d.Build, "#>>> auto generate by ll-pica begin")
+	d.Build = append(d.Build, []string{
+		"#>>> auto generate by ll-pica begin",
+		"set -x",
+	}...)
 
 	// 设置 linglong/sources 目录
 	d.Build = append(d.Build, []string{
+		"# set the local sources directory",
+		fmt.Sprintf("EXTERNAL_DEB_SOURCES=\"%s\"", comm.LlLocalSourceDir),
 		"# set the linglong/sources directory",
 		fmt.Sprintf("SOURCES=\"%s\"", comm.LlSourceDir),
-		fmt.Sprintf("dpkg-deb -x $SOURCES/%s $SOURCES/%s", filepath.Base(d.Filename), d.Name),
 	}...)
 
 	d.PackageKind = "app"
@@ -360,10 +358,10 @@ func (d *Deb) GenerateBuildScript() {
 		execLine = pattern.ReplaceAllLiteralString(execLine, fmt.Sprintf("/opt/apps/%s/files/", d.Id))
 
 		iconValue = fs.TransIconToLl(desktopData["Desktop Entry"]["Icon"])
-		index := strings.Index(desktop, comm.LlSourceDir)
+		index := strings.Index(desktop, comm.LlLocalSourceDir)
 		if index != -1 {
 			// 如果找到了子串，则移除它及其之前的部分
-			modiDesktopPath := "$SOURCES" + desktop[index+len(comm.LlSourceDir):]
+			modiDesktopPath := "$EXTERNAL_DEB_SOURCES" + desktop[index+len(comm.LlLocalSourceDir):]
 			d.Build = append(d.Build, []string{
 				"# modify desktop, Exec and Icon should not contanin absolut paths",
 				fmt.Sprintf("sed -i '/Exec*/c\\Exec=%s' %s", execLine, modiDesktopPath),
@@ -380,22 +378,28 @@ func (d *Deb) GenerateBuildScript() {
 			if execFile == "" {
 				continue
 			}
-			index := strings.Index(execFile, comm.LlSourceDir)
+			index := strings.Index(execFile, comm.LlLocalSourceDir)
 			if index != -1 {
 				// 如果找到了子串，则移除它及其之前的部分
-				modiExecFilePath := "$SOURCES" + execFile[index+len(comm.LlSourceDir):]
+				modiExecFilePath := "$EXTERNAL_DEB_SOURCES" + execFile[index+len(comm.LlLocalSourceDir):]
 				d.Build = append(d.Build, []string{
 					fmt.Sprintf("sed -i 's/%s/%s/g' %s", d.Name, d.Id, modiExecFilePath),
 				}...)
 			}
 		}
 	}
+	
+	if len(d.Sources) > 0 {
+		d.Build = append(d.Build, []string{
+			"find $SOURCES -type f -name \"*.deb\" >> $DEPS_LIST || exit 1",
+		}...)
+	}
 
 	// 玲珑内部的 /opt/apps 路径拼接的是 linglong-id
 	d.Build = append(d.Build, []string{
 		"OUT_DIR=\"$(mktemp -d)\"", // 临时目录，处理完内容再移动到$PREFIX
 		"DEPS_LIST=\"$OUT_DIR/DEPS.list\"",
-		"find $SOURCES -type f -name \"*.deb\" > $DEPS_LIST",
+		"find $EXTERNAL_DEB_SOURCES -type f -name \"*.deb\" >> $DEPS_LIST || exit 1",
 		"DATA_LIST_DIR=\"$OUT_DIR/data\"", // 包数据存放的临时目录
 		"mkdir -p /tmp/deb-source-file",   // 用于记录安装的所有文件来自哪个包
 		"while IFS= read -r file",
@@ -448,8 +452,8 @@ func (d *Deb) GenerateBuildScript() {
 		d.Build = append(d.Build, []string{
 			"",
 			"# move files",
-			fmt.Sprintf("cp -r $SOURCES/%s/opt/apps/%s/entries/* $PREFIX/share", d.Name, realPackageName),
-			fmt.Sprintf("cp -rf $SOURCES/%s/opt/apps/%s/files/* $PREFIX", d.Name, realPackageName),
+			fmt.Sprintf("cp -r $EXTERNAL_DEB_SOURCES/%s/opt/apps/%s/entries/* $PREFIX/share", d.Name, realPackageName),
+			fmt.Sprintf("cp -rf $EXTERNAL_DEB_SOURCES/%s/opt/apps/%s/files/* $PREFIX", d.Name, realPackageName),
 		}...)
 	}
 
@@ -457,7 +461,7 @@ func (d *Deb) GenerateBuildScript() {
 		d.Build = append(d.Build, []string{
 			"",
 			"# move files",
-			fmt.Sprintf("cp -r $SOURCES/%s/usr/* $PREFIX", d.Name),
+			fmt.Sprintf("cp -r $EXTERNAL_DEB_SOURCES/%s/usr/* $PREFIX", d.Name),
 		}...)
 	}
 
@@ -598,20 +602,10 @@ func (d *Deb) GetPackageList(distro string) {
 					var e error
 
 					// 跳过黑名单
-					if delMap[strings.Split(task.File.Filename, "_")[0]] {
+					if d.DelMap[strings.Split(task.File.Filename, "_")[0]] {
 						continue
 					}
 
-					// 构造下载路径
-					task.TempDownPath = filepath.Join(filepath.Dir(d.Path), task.File.Filename)
-					// 下载文件
-					e = context.Downloader().DownloadWithChecksum(
-						context,
-						repo.PackageURL(task.File.DownloadURL()).String(),
-						task.TempDownPath,
-						&task.File.Checksums,
-						false)
-
 					source := comm.Source{
 						Kind:   "file",
 						Url:    repo.PackageURL(task.File.DownloadURL()).String(),
