@@ -27,6 +27,7 @@ type LinglongBuilder struct {
 	Sources    []comm.Source `yaml:"sources"`
 	Build      []string      `yaml:"-"`
 	BuildInput string        `yaml:"build"` // 用来接收build字段，从yaml文件读入的值
+	BuildExt   BuildExt      `yaml:"buildext"`
 }
 
 type LinglongCli struct {
@@ -43,6 +44,15 @@ type Package struct {
 	Description string `yaml:"description"`
 }
 
+type BuildExt struct {
+	Apt AptExt `yaml:"apt"`
+}
+
+type AptExt struct {
+	BuildDepends []string `yaml:"build_depends"`
+	Depends      []string `yaml:"depends"`
+}
+
 const LinglongBuilderTMPL = `version: "1"
 
 package:
@@ -65,14 +75,36 @@ sources:
 {{- range .Sources}}
   - kind: {{.Kind}}
     url: {{.Url}}
+  {{- if .Version}}
+    version: {{.Version}}
+  {{- end}}
+  {{- if eq .Kind "git" }}
+    commit: {{.Commit}}
+  {{- else}}
     digest: {{.Digest}}
+  {{- end}}
 {{end}}
 {{- end}}
 build: |
-  set -x
   {{- range $line := .Build}}
   {{- printf "\n  %s" $line}}
   {{- end}}
+{{- if or (gt (len .BuildExt.Apt.BuildDepends) 0) (gt (len .BuildExt.Apt.Depends) 0) }}
+buildext:
+  apt:
+    {{- if .BuildExt.Apt.BuildDepends }}
+    build_depends:
+      {{- range .BuildExt.Apt.BuildDepends }}
+      - {{.}}
+      {{- end }}
+    {{- end }}
+    {{- if .BuildExt.Apt.Depends }}
+    depends:
+      {{- range .BuildExt.Apt.Depends }}
+      - {{.}}
+      {{- end }}
+    {{- end }}
+{{- end }}
 `
 
 func NewLinglongBuilder() *LinglongBuilder {
@@ -155,7 +187,7 @@ func (ts *LinglongBuilder) CreateLinglongBuilder(path string) bool {
 
 // 调用 ll-builder build
 func (ts *LinglongBuilder) LinglongBuild(path string, cmd string) bool {
-	if ret, msg, err := comm.ExecAndWait(300, "sh", "-c",
+	if ret, msg, err := comm.ExecAndWait(1<<11, "sh", "-c",
 		fmt.Sprintf("cd %s && %s", path, cmd)); err != nil {
 		log.Logger.Fatalf("msg: %+v err:%+v, out: %+v", msg, err, ret)
 	} else {
@@ -214,14 +246,29 @@ func (cli *LinglongCli) GetBaseInsPack() []string {
 	config.ReadConfigJson()
 
 	cli.LinglongCliInstall(config.BaseId, config.BaseVersion)
-	// 获取 base 的 info
-	cli.LinglongCliInfo(config.BaseId)
+
+	// 先检查文件是否存在
+	commit := comm.GetBaseRuntimeCommit(config.BaseId, config.BaseVersion)
+	if commit == "" {
+		log.Logger.Warnf("failed to get base commit for %s/%s", config.BaseId, config.BaseVersion)
+		return packages
+	}
+
+	statusFile := fmt.Sprintf("/var/lib/linglong/layers/%s/files/var/lib/dpkg/status", commit)
+	if ret, _ := fs.CheckFileExits(statusFile); !ret {
+		log.Logger.Warnf("status file not found: %s", statusFile)
+		return packages
+	}
+
 	if ret, msg, err := comm.ExecAndWait(60, "sh", "-c",
-		fmt.Sprintf("cat /var/lib/linglong/layers/%s/%s/%s/%s/runtime/files/var/lib/dpkg/status | awk -F': ' '/^Package: /{a=a\",\"$2} END{sub(/^,/,\"\",a);printf a}'",
-			cli.Channel, config.BaseId, cli.Version, cli.Arch[0])); err != nil {
+		fmt.Sprintf("cat %s | awk -F': ' '/^Package: /{a=a\",\"$2} END{sub(/^,/,\"\",a);printf a}'", statusFile)); err != nil {
 		log.Logger.Warnf("cat dpkg/status error: %s", msg)
+		return packages
 	} else {
-		packages = append(packages, strings.Split(ret, ",")...)
+		// 只有当 ret 不为空时才处理
+		if strings.TrimSpace(ret) != "" {
+			packages = append(packages, strings.Split(ret, ",")...)
+		}
 	}
 	return packages
 }
@@ -235,21 +282,57 @@ func (cli *LinglongCli) GetRuntimeInsPack() []string {
 	config.ReadConfigJson()
 
 	cli.LinglongCliInstall(config.Id, config.Version)
-	// 获取 runtime 的 info
-	cli.LinglongCliInfo(config.Id)
+
+	// 先检查文件是否存在
+	commit := comm.GetBaseRuntimeCommit(config.Id, config.Version)
+	if commit == "" {
+		log.Logger.Warnf("failed to get runtime commit for %s/%s", config.Id, config.Version)
+		return packages
+	}
+
+	packagesFile := fmt.Sprintf("/var/lib/linglong/layers/%s/files/packages.list", commit)
+	if ret, _ := fs.CheckFileExits(packagesFile); !ret {
+		log.Logger.Warnf("packages.list file not found: %s", packagesFile)
+		return packages
+	}
+
 	if ret, msg, err := comm.ExecAndWait(60, "sh", "-c",
-		fmt.Sprintf("cat /var/lib/linglong/layers/%s/%s/%s/%s/runtime/files/packages.list | awk -F': ' '/^Package: /{a=a\",\"$2} END{sub(/^,/,\"\",a);printf a}'",
-			cli.Channel, config.Id, cli.Version, cli.Arch[0])); err != nil {
+		fmt.Sprintf("cat %s | awk -F': ' '/^Package: /{a=a\",\"$2} END{sub(/^,/,\"\",a);printf a}'", packagesFile)); err != nil {
 		log.Logger.Warnf("cat runtime/package.list error: %s", msg)
+		return packages
 	} else {
-		packages = append(packages, strings.Split(ret, ",")...)
+		// 只有当 ret 不为空时才处理
+		if strings.TrimSpace(ret) != "" {
+			packages = append(packages, strings.Split(ret, ",")...)
+		}
 	}
 	return packages
 }
 
 func (cli *LinglongCli) LinglongCliInstall(appid, version string) {
+	// 先检查是否已安装
+	if cli.IsPackageInstalled(appid, version) {
+		log.Logger.Infof("Package %s/%s already installed, skipping", appid, version)
+		return
+	}
+
+	// 如果未安装才执行安装
 	if ret, _, err := comm.ExecAndWait(1<<20, "sh", "-c",
 		fmt.Sprintf("ll-cli install %s/%s", appid, version)); err != nil {
 		log.Logger.Infof("out: %+v", ret)
 	}
 }
+
+// 检查包是否已安装
+func (cli *LinglongCli) IsPackageInstalled(appid, version string) bool {
+	// v25后base runtime分开，这里整合 base 和 runtime的输出，然后统一查找
+	if ret, _, err := comm.ExecAndWait(10, "sh", "-c",
+		fmt.Sprintf("ll-cli list --type=base && ll-cli list --type=runtime | grep %s", appid)); err == nil {
+		// 检查输出中是否包含指定的appid和version
+		if strings.Contains(ret, appid) && strings.Contains(ret, version) {
+			return true
+		}
+	}
+
+	return false
+}
